.. Spotted dmi bot documentation master file, created by
   sphinx-quickstart on Sun Feb 28 14:11:58 2021.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Spotted dmi bot's documentation
===========================================
You can find this bot live on telegram `@Spotted_DMI_bot <https://telegram.me/Spotted_DMI_bot>`_

For the complete source code, check this github `repo <https://github.com/UNICT-DMI/Telegram-SpottedDMI-Bot/tree/main>`_

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   Overview <readme>
   Database Schema <dbschema>
   Privacy Policy <privacy>
   Modules <api/modules>

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
